#!/usr/bin/env bash

# ------------------------------------------------------------------------------
# Description
# -----------
#  Version 0.2
#  Completion script for shell_gpt (https://github.com/TheR1D/shell_gpt)
#
# ------------------------------------------------------------------------------
# Authors
# -------
#
#  * OleksaOryshchyn (https://github.com/eiger8)
#
# ------------------------------------------------------------------------------

# @option --model[`_choice_model`]                          Large language model to use. [default: gpt-4-1106-preview]
# @option --temperature <number>                            Randomness of generated output. FLOAT RANGE [0.0<=x<=2.0] [default: 0.0]
# @option --top-p <nubber>                                  Limits highest probable tokens (words). FLOAT RANGE [0.0<=x<=2.0] [default: 1.0]
# @flag --editor                                             Open $EDITOR to provide a prompt. [default: no-editor]
# @flag --no-editor                                          Run ShellGPT in terminal/shell prompt.
# @flag --cache                                              Cache completion results. [default: cache]
# @flag --no-cache                                           Generate answers without previously cached context.
# @flag --version                                            Show version.
# @flag --help                                               Show this message and exit.
# @flag -s --shell                                           Generate and execute shell commands.
# @flag --interaction                                        Interactive mode for --shell option. [default: interaction]
# @flag --no-interaction                                     Non-interactive mode. This will print generated command to stdout.
# @flag -d --describe-shell                                  Describe a shell command.
# @flag -c --code                                            Generate only code.
# @flag --functions                                          Allow function calls. [default: functions]
# @flag --no-functions                                       Disallow function calls.
# @option --chat[`_choice_chats`]                           Follow conversation with id, use "temp" for quick session. [default: None]
# @option --repl <value>                                    Start a REPL (Read–eval–print loop) session. [default: None]
# @option --show-chat[`_choice_chats`]                      Show all messages from provided chat id. [default: None]
# @flag -lc                                                  List all existing chat ids.
# @flag --list-chats                                         List all existing chat ids.
# @option --role[`_choice_role`]                            System role for GPT model. [default: None]
# @option --create-role <value>                             Create role. [default: None]
# @option --show-role[`_choice_role`]                       Show role. [default: None]
# @flag -lr                                                  List roles.
# @flag --list-roles                                         List roles.
# @flag --install-integration                                Install shell (bash|zsh) integration to use Ctrl+L binging to invoke ShellGPT.

. "$ARGC_COMPLETIONS_ROOT/utils/_argc_utils.sh"

_choice_role() {
    sgpt --list-roles | sed -E 's|.*/roles/(.*)\.json|\1|'
}

_choice_chats() {
    sgpt --list-chats | sed -E 's|.*/chat_cache/(.*)|\1|'
}

_choice_model() {
    local OPENAI_API_KEY=$(grep '^OPENAI_API_KEY=' ~/.config/shell_gpt/.sgptrc | cut -d '=' -f2)
    curl -s https://api.openai.com/v1/models -H "Content-Type: application/json" -H "Authorization: Bearer $OPENAI_API_KEY" | jq -r '.data[].id'
}

command eval "$(argc --argc-eval "$0" "$@")"